@@ -27,8 +27,6 @@
  * 02110-1301  USA
  */
 
-!function(jschardet) {
-
 // GB2312 most frequently used character table
 //
 // Char to FreqOrder table , from hz6763
@@ -43,11 +41,11 @@
 //
 // Typical Distribution Ratio about 25% of Ideal one, still much higher that RDR
 
-jschardet.GB2312_TYPICAL_DISTRIBUTION_RATIO = 0.9;
+exports.GB2312_TYPICAL_DISTRIBUTION_RATIO = 0.9;
 
-jschardet.GB2312_TABLE_SIZE = 3760;
+exports.GB2312_TABLE_SIZE = 3760;
 
-jschardet.GB2312CharToFreqOrder = [
+exports.GB2312CharToFreqOrder = [
 1671, 749,1443,2364,3924,3807,2330,3921,1704,3463,2691,1511,1515, 572,3191,2205,
 2361, 224,2558, 479,1711, 963,3162, 440,4060,1905,2966,2947,3580,2647,3961,3842,
 2204, 869,4207, 970,2678,5626,2944,2956,1479,4048, 514,3595, 588,1346,2820,3409,
@@ -473,5 +471,3 @@ jschardet.GB2312CharToFreqOrder = [
 5867,5507,6273,4206,6274,4789,6098,6764,3619,3646,3833,3804,2394,3788,4936,3978,
 4866,4899,6099,6100,5559,6478,6765,3599,5868,6101,5869,5870,6275,6766,4527,6767
 ];
-
-}(require('./init'));
